Module constants

Module constants 

Constants used throughout 3DM.

These constants mirror those in the Java Measure class.

Constants

ATTR_INFO
Info bytes in the presence of an attribute ($c_a$ in thesis).
ATTR_VALUE_THRESHOLD
Attribute values less than this have an info size of 1 ($c_v$ in thesis).
COPY_THRESHOLD
Minimum info bytes for copy detection (from HeuristicMatching).
DFS_MATCH_THRESHOLD
Max distance for fuzzy DFS matching.
EDGE_BYTES
Info bytes per tree edge.
ELEMENT_NAME_INFO
Info bytes in an element name ($c_e$ in thesis).
MAX_DIST
Maximum distance value. Distance is normalized between 0 and MAX_DIST.
MAX_FUZZY_MATCH
Max distance for candidate fuzzy matching.
PENALTY_C
Penalty term ($c_p$ in thesis).
TEXT_THRESHOLD
Text nodes shorter than this have an info size of 1 ($c_t$ in thesis).
ZERO_CHILDREN_MATCH
Distance to return by child_list_distance if both nodes have 0 children.