Diff and Patch algorithms for XML trees.
This module provides functionality to generate diffs between matched trees and to apply those diffs to reconstruct modified versions.
Structs
- BfsIndex
- Index that maps nodes to sequential IDs using BFS order.
- Diff
- Diff generator for matched trees.
- Diff
Operation - A diff operation with source, destination, and run count.
- Patch
- Patch application for applying diffs to base trees.
Constants
- DIFF_
COPY_ TAG - Tag names for diff operations.
- DIFF_
CPYDST_ ATTR - DIFF_
CPYRUN_ ATTR - DIFF_
CPYSRC_ ATTR - Attribute names for diff operations.
- DIFF_
ESC_ TAG - DIFF_
INSERT_ TAG - DIFF_NS
- Default namespace for diff tags.
- DIFF_
ROOTOP_ ATTR - DIFF_
ROOTOP_ INS - Value for root insert operation.
- DIFF_
ROOT_ TAG