Module matching

Module matching 

Tree matching algorithms.

This module provides algorithms for establishing correspondences between nodes in base and branch trees. The matching is used by the merge algorithm to identify which nodes have been modified, moved, copied, or deleted.

Modules

constants
Constants used by matching algorithms.

Structs

CandidateEntry
A candidate match entry with distance metrics.
DfsTreeIterator
Iterator for traversing a tree in depth-first order.
DiffMatching
Tree matching algorithm optimized for diff generation.
HeuristicMatching
Heuristic matching algorithm for building correspondences between trees.
TriMatching
Matching between a base and two branch trees.

Traits

Matching
Trait for tree matching algorithms.