pub struct BaseNode;Expand description
Helper functions for base nodes.
Implementations
Sourceimpl BaseNode
impl BaseNode
Sourcepub fn swap_left_right_matchings(node: &NodeRef)
pub fn swap_left_right_matchings(node: &NodeRef)
Sourcepub fn child(node: &NodeRef, index: usize) -> NodeRef
pub fn child(node: &NodeRef, index: usize) -> NodeRef
Gets the child at the given index, asserting it’s a base node.
Panics
Panics if the index is out of bounds or if the child is not a base node.