Module branch

Module branch 

Branch node helper functions.

This module provides helper functions for working with branch nodes. Branch nodes are nodes in a branch tree (left or right) that are matched to nodes in the base tree.

Structs

BranchNode
Helper functions for branch nodes.