Constants used throughout 3DM.
These constants mirror those in the Java Measure class.
Constants
- ATTR_
INFO - Info bytes in the presence of an attribute ($c_a$ in thesis).
- ATTR_
VALUE_ THRESHOLD - Attribute values less than this have an info size of 1 ($c_v$ in thesis).
- COPY_
THRESHOLD - Minimum info bytes for copy detection (from HeuristicMatching).
- DFS_
MATCH_ THRESHOLD - Max distance for fuzzy DFS matching.
- EDGE_
BYTES - Info bytes per tree edge.
- ELEMENT_
NAME_ INFO - Info bytes in an element name ($c_e$ in thesis).
- MAX_
DIST - Maximum distance value. Distance is normalized between 0 and MAX_DIST.
- MAX_
FUZZY_ MATCH - Max distance for candidate fuzzy matching.
- PENALTY_
C - Penalty term ($c_p$ in thesis).
- TEXT_
THRESHOLD - Text nodes shorter than this have an info size of 1 ($c_t$ in thesis).
- ZERO_
CHILDREN_ MATCH - Distance to return by child_list_distance if both nodes have 0 children.