Tree matching algorithms.
This module provides algorithms for establishing correspondences between nodes in base and branch trees. The matching is used by the merge algorithm to identify which nodes have been modified, moved, copied, or deleted.
Modules
- constants
- Constants used by matching algorithms.
Structs
- Candidate
Entry - A candidate match entry with distance metrics.
- DfsTree
Iterator - Iterator for traversing a tree in depth-first order.
- Diff
Matching - Tree matching algorithm optimized for diff generation.
- Heuristic
Matching - Heuristic matching algorithm for building correspondences between trees.
- TriMatching
- Matching between a base and two branch trees.
Traits
- Matching
- Trait for tree matching algorithms.