Base node helper functions.
This module provides helper functions for working with base nodes. Base nodes are nodes in the base tree that are matched to two branch trees (left and right).
Structs
- Base
Node - Helper functions for base nodes.