BaseNode

Struct BaseNode 

pub struct BaseNode;
Helper functions for base nodes.

Implementations

Source

impl BaseNode

pub fn left(node: &NodeRef) -> Rc<RefCell<MatchedNodes>>

Returns the left MatchedNodes for a base node.

Panics

Panics if the node is not a base node.

pub fn right(node: &NodeRef) -> Rc<RefCell<MatchedNodes>>

Returns the right MatchedNodes for a base node.

Panics

Panics if the node is not a base node.

pub fn swap_left_right_matchings(node: &NodeRef)

Swaps the left and right matchings.

Panics

Panics if the node is not a base node.

pub fn child(node: &NodeRef, index: usize) -> NodeRef

Gets the child at the given index, asserting it’s a base node.

Panics

Panics if the index is out of bounds or if the child is not a base node.

pub fn parent(node: &NodeRef) -> Option<NodeRef>

Gets the parent, asserting it’s a base node.

Returns None if there is no parent.

Panics

Panics if the parent exists but is not a base node.

pub fn is_base(node: &NodeRef) -> bool

Checks if the given node is a base node.